﻿#Region "LICENSE"
'
' Copyright (c) Microncode.com
' 
' This source is subject to the Microsoft Public License. 
' See https://opensource.org/licenses/ms-pl.html.
' All other rights reserved. 
' 
' THIS CODE And INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
' EITHER EXPRESSED Or IMPLIED, INCLUDING BUT Not LIMITED TO THE IMPLIED 
' WARRANTIES OF MERCHANTABILITY And/Or FITNESS FOR A PARTICULAR PURPOSE. 
'
#End Region

''' <summary>
''' The main example of using the CSFreeDB library.
''' </summary>
Public Class frmFreeDB

    Friend WithEvents FreeDB1 As CSFreeDB.FreeDB

    ''' <summary>
    ''' Form load.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub frmFreeDB_Load(sender As Object, e As EventArgs) Handles MyBase.Load

        Me.FreeDB1 = New CSFreeDB.FreeDB()

        FreeDB1.UserName = "Your email"
        FreeDB1.UserKey = "Your registration key"

        cboDevice.DataSource = FreeDB1.DrivesInfo

    End Sub

    ''' <summary>
    ''' The information about the album.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub FreeDB1_FreeDBAlbum(sender As Object, e As CSFreeDBLib.FreeDB.AlbumInfo) Handles FreeDB1.FreeDBAlbum

        lblArtist.Text = "Artist: " & e.AlbumArtist
        lblAlbum.Text = "Album: " & e.AlbumName
        lblAlbumDiscID.Text = "Album: " & e.AlbumDiscID

    End Sub

    ''' <summary>
    ''' When done.
    ''' </summary>
    ''' <param name="sender"></param>
    Private Sub FreeDB1_FreeDBDone(sender As Object) Handles FreeDB1.FreeDBDone

        toolStripStatusLabel1.Text = "Done."

    End Sub

    ''' <summary>
    ''' On error.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub FreeDB1_FreeDBError(sender As Object, e As CSFreeDB.Core.MessageArgs) Handles FreeDB1.FreeDBError

        MessageBox.Show(e.String & "(" & e.Number & ")")
        toolStripStatusLabel1.Text = e.String & "(" & e.Number & ")"

    End Sub

    ''' <summary>
    ''' When the status has changed.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub FreeDB1_FreeDBStatus(sender As Object, e As CSFreeDB.Core.MessageArgs) Handles FreeDB1.FreeDBStatus

        Console.WriteLine(e.String)
        toolStripStatusLabel1.Text = e.String

    End Sub

    ''' <summary>
    ''' The information about the tracks.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub FreeDB1_FreeDBTracks(sender As Object, e As CSFreeDBLib.FreeDB.TrackInfo) Handles FreeDB1.FreeDBTracks

        Console.WriteLine(e.TrackName)
        lstTracks.Items(e.TrackNumber - 1).SubItems(1).Text = e.TrackName

    End Sub

    ''' <summary>
    ''' Open the door of the CD drive.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnOpen_Click(sender As Object, e As EventArgs) Handles btnOpen.Click

        lstTracks.Items.Clear()
        FreeDB1.CDEject(cboDevice.SelectedIndex)

    End Sub

    ''' <summary>
    ''' Close the door of the CD drive.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnClose_Click(sender As Object, e As EventArgs) Handles btnClose.Click

        lstTracks.Items.Clear()
        FreeDB1.CDClose(cboDevice.SelectedIndex)

    End Sub

    ''' <summary>
    ''' Refresh the CD tracks.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub btnRefresh_Click(sender As Object, e As EventArgs) Handles btnRefresh.Click

        LoadCDTracks()

    End Sub

    ''' <summary>
    ''' Load the CD tracks to the list view.
    ''' </summary>
    ''' <returns></returns>
    Private Function LoadCDTracks() As Integer
        If FreeDB1.CDIsReady(cboDevice.SelectedIndex) = False Then
            MessageBox.Show("The CD is not ready. Please insert an Audio CD to the drive.")
            Return -1
        Else
            lstTracks.Items.Clear()
            Dim arr As String() = New String(5) {}
            Dim itm As ListViewItem

            For Each track As CSFreeDB.FreeDB.TrackInfo In FreeDB1.GetTracks(cboDevice.SelectedIndex)
                arr(0) = track.TrackNumber.ToString()
                arr(1) = "Track" & track.TrackNumber.ToString("D2") & ".cda"
                arr(2) = track.TrackLength.ToString("hh\:mm\:ss")
                arr(3) = track.TrackBytes.ToString()
                arr(4) = track.TrackType
                arr(5) = track.TrackFile
                itm = New ListViewItem(arr)
                lstTracks.Items.Add(itm)
            Next

            If lstTracks.Items.Count > 0 Then
                lstTracks.Items(0).Selected = True
            End If

            Return 0
        End If
    End Function

    ''' <summary>
    ''' Load the track from the selected audio CD.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cboDevice_SelectedIndexChanged(sender As Object, e As EventArgs) Handles cboDevice.SelectedIndexChanged

        LoadCDTracks()

    End Sub

    ''' <summary>
    ''' Load the FreeDB information.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdLoadFreeDB_Click(sender As Object, e As EventArgs) Handles cmdLoadFreeDB.Click

        If FreeDB1.CDIsReady(cboDevice.SelectedIndex) = False Then

            MessageBox.Show("The CD is not ready. Please insert an audio cd to the drive.")
            Return

        Else

            'Call the FreeDB and receive the data in the events:
            FreeDB1.GetFreeDBInfo(cboDevice.SelectedIndex)

        End If

    End Sub

    ''' <summary>
    ''' Load the FreeDB information in Async mode.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdLoadFreeDBAsync_Click(sender As Object, e As EventArgs) Handles cmdLoadFreeDBAsync.Click

        Dim cntr As Integer = 0

        For Each trckFreeDB As String In FreeDB1.GetFreeDBInfoAsync(cboDevice.SelectedIndex).FreeDBTracksInfo
            lstTracks.Items(cntr).SubItems(1).Text = trckFreeDB.ToString()
            cntr = cntr + 1
        Next

        If cntr > 0 Then
            lblArtist.Text = "Artist: " & FreeDB1.GetFreeDBInfoAsync(cboDevice.SelectedIndex).Artist
            lblAlbum.Text = "Album: " & FreeDB1.GetFreeDBInfoAsync(cboDevice.SelectedIndex).AlbumName
            lblAlbumDiscID.Text = "DiscID: " & FreeDB1.GetFreeDBInfoAsync(cboDevice.SelectedIndex).DiscID
        End If

    End Sub

    ''' <summary>
    ''' Check the license.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdOrderLicense_Click(sender As Object, e As EventArgs) Handles cmdOrderLicense.Click

        ' In order to get your own UserName and RegKey and to distribute this library
        ' with your own projects for commercial or any other purpose, please order a license at:
        ' https://www.microncode.com/developers/cs-freedb/?cmd=order

        System.Diagnostics.Process.Start("https://www.microncode.com/developers/cs-freedb/?cmd=order")

    End Sub

End Class
